@@ -1,6 +1,6 @@
 spher.spcauchy.contour <- function(mu, rho, bgcol = "snow", dat = NULL, col = NULL, lat = 50, long = 50) {
   m1 <- mu
-  m <- euclid.inv(m1)
+  m <- Directional::euclid.inv(m1)
   x1 <- seq(m[1] - lat, m[1] + lat, by = 0.1)
   x2 <- seq(m[2] - long, m[2] + long, by = 0.1)
   n <- length(x1)
@@ -26,7 +26,7 @@ spher.spcauchy.contour <- function(mu, rho, bgcol = "snow", dat = NULL, col = NU
   rgl::contourLines3d(ids, list(latitude = function(x, y, z) asin( z / sqrt(x^2 + y^2 + z^2) ) * 180 / pi,
                                 longitude = function(x, y, z) atan2(y, x) * 180 / pi) )
   for ( i in 1:length(a) ) {
-    y1 <- euclid( cbind( a[[ i ]]$x, a[[ i ]]$y ) )
+    y1 <- Directional::euclid( cbind( a[[ i ]]$x, a[[ i ]]$y ) )
     rgl::lines3d(y1[, 1], y1[, 2], y1[, 3], col = 4, radius = 1, size = 1)
   }
   rgl::points3d(m1[1], m1[2], m1[3], col = 3, radius = 1, size = 3)
